import React from 'react'
import { Image, Menu, Dropdown, Popup, Sticky } from 'semantic-ui-react'
import useTranslation from 'next-translate/useTranslation'
import { useRouter } from 'next/router';
import Link from 'next/link';
import setLanguage from 'next-translate/setLanguage'
import i18nConfig from '../i18n.json'

const { locales } = i18nConfig
const countries = require('../i18nCountries.json')

console.log("Countries :", countries)

const Navigation = () => {
	const router = useRouter()
	const { locale } = router
	//const setLang = async (country) => await setLanguage(country)

	const { t, lang } = useTranslation('spotnikgui')
  
	const configText = () => {
		let cRoute = router.pathname
		//let config = cRoute.startsWith('/configuration')
		//if (!config) { return t("menuConfig")}
		if (cRoute === '/configuration/configspotnik') { return t("menuConfigSpotnik")}
		if (cRoute === '/configuration/configgenerale') { return t("menuConfigGenerale")}
		if (cRoute === '/configuration/configsalonsana') { return t("menuConfigSalonsAna")}
		if (cRoute === '/configuration/configRaptor') { return t("menuConfigRaptor")}
      //console.log("configText = ", cRoute, " -- ", t("menuConfigSpotnik"))
		return t("menuConfig")
	}

	console.log("Locales :", locales)
	let Options = locales.map( (loc) => {
		let opt = { key: loc, value: loc,	flag: countries.flags[loc], text: countries.languages[loc]}
		return opt
	})



	return (
		<>
		<Sticky>
      		<Menu  color="blue" borderless inverted style={{fontSize:"1.2em", borderRadius:"0", margin:"0"}}>
				<Menu.Item key="logo">
					<Image src="/spotnik_white.svg" alt="Logo Spotnik" style={{ width: '1.5em', height: '1.5em', marginRight:'0.5em' }} />
					<span>spotnik</span>
				</Menu.Item>
				<Menu.Item key="menuHome" active = {router.pathname === '/'} >
					<Link href='/' locale={locale} >
						<a>{t("menuHome")}</a>
					</Link>
				</Menu.Item>
				<Menu.Item key="menuDtmf" active = {router.pathname === '/dtmfcmd'} >
					<Link href='/dtmfcmd' locale={locale} >
						<a>{t("menuDtmf")}</a>
					</Link>
				</Menu.Item>
				<Menu.Item key="menuKeypad" active = {router.pathname === '/keypad'} >
					<Link href='/keypad' locale={locale} >
						<a>{t("menuKeypad")}</a>
					</Link>
				</Menu.Item>
			  
			    {/*<Menu.Item  active = {router.pathname.startsWith('/configuration')} >*/}
					<Dropdown key="mnuConfig" item text={configText()} style={{fontSize:"1em"}}>	
					<Dropdown.Menu key="menuConfig" style={{borderColor: '#2185d0'}} >
						<>
							<Dropdown.Item key="menuConfigGenerale">
								<Link href="/configuration/configgenerale" locale={locale} >
									<a className="ui">{t("menuConfigGenerale")}</a>
								</Link>
							</Dropdown.Item>
							<Dropdown.Item key="menuConfigSpotnik">
								<Link href="/configuration/configspotnik" locale={locale} >
									<a className="ui">{t("menuConfigSpotnik")}</a>
								</Link>
							</Dropdown.Item>
							<Dropdown.Item key="menuConfigSalonsAna">
								<Link href="/configuration/configsalonsana" locale={locale} >
									<a className="ui">{t("menuConfigSalonsAna")}</a>
								</Link>
							</Dropdown.Item>
							<Dropdown.Item key="menuConfigRaptor">
								<Link href="/configuration/configRaptor" locale={locale} >
									<a className="ui">{t("menuConfigRaptor")}</a>
								</Link>
							</Dropdown.Item>
						</>
					</Dropdown.Menu>
				</Dropdown>
				{/*</Menu.Item>*/}

				<Menu.Item key="menuStatus"  active = {router.pathname === '/status'} >
					<Link href='/status' locale={locale} >
						<a>{t("menuStatus")}</a>
					</Link>
				</Menu.Item>
				<Menu.Item key="menuAdmin" active = {router.pathname === '/admin'} >
					<Link href='/admin' locale={locale} >
						<a>{t("menuAdmin")}</a>
					</Link>
				</Menu.Item>
				<Menu.Item key="menuAbout" active = {router.pathname === '/about'} >
					<Link href='/about' locale={locale} >
						<a>{t("menuAbout")}</a>
					</Link>
				</Menu.Item>
			  
			<Menu.Item key="lang" position='right'>
				<Popup 
					content = {t('chooseLangGUI')}
					trigger = {<Dropdown key="country" 
                          item
						  placeholder="Select Your Region"
                          value={locale}
                          onChange={(e, { value }) => {
							  (async (country) => await setLanguage(country))(value)
                          }}
                          options={Options}
					/>}
				/>
				</Menu.Item>
						
			</Menu>
		</Sticky>
		</>
	)
}

export default Navigation